@@ -15,7 +15,7 @@
     <message>
         <location filename="AddPost.py" line="61"/>
         <source>Edit post</source>
-        <translation type="obsolete">Редактирование поста</translation>
+        <translation type="obsolete">Изменить</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="106"/>
@@ -43,7 +43,7 @@
         <translation type="obsolete">Отправка</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="433"/>
+        <location filename="AddPost.py" line="442"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
@@ -63,9 +63,9 @@
         <translation type="obsolete">Пост изменен</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="247"/>
+        <location filename="AddPost.py" line="265"/>
         <source>Add picture</source>
-        <translation type="unfinished">Добавить рисунок</translation>
+        <translation type="unfinished">Добавить изображение</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="226"/>
@@ -73,14 +73,14 @@
         <translation type="obsolete">Добавить ссылку на рисунок</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="415"/>
+        <location filename="AddPost.py" line="424"/>
         <source>Add</source>
         <translation type="unfinished">Добавить</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="276"/>
+        <location filename="AddPost.py" line="294"/>
         <source>Add link</source>
-        <translation type="unfinished">Добавить ссылку</translation>
+        <translation type="unfinished">Ссылка</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="257"/>
@@ -93,52 +93,52 @@
         <translation type="obsolete">Добавить html теги</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="317"/>
+        <location filename="AddPost.py" line="336"/>
         <source>Bold</source>
         <translation type="unfinished">Жирный</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="319"/>
+        <location filename="AddPost.py" line="338"/>
         <source>Italic</source>
         <translation type="unfinished">Курсив</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="321"/>
+        <location filename="AddPost.py" line="340"/>
         <source>Center</source>
         <translation type="unfinished">По центру</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="323"/>
+        <location filename="AddPost.py" line="342"/>
         <source>Right</source>
         <translation type="unfinished">По правому краю</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="325"/>
+        <location filename="AddPost.py" line="344"/>
         <source>Left</source>
         <translation type="unfinished">По левому краю</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="327"/>
+        <location filename="AddPost.py" line="346"/>
         <source>Justify</source>
         <translation type="unfinished">По ширине</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="329"/>
+        <location filename="AddPost.py" line="348"/>
         <source>Color</source>
         <translation type="unfinished">Цвет</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="371"/>
+        <location filename="AddPost.py" line="378"/>
         <source>Color text</source>
-        <translation type="unfinished">Цветной текст</translation>
+        <translation type="obsolete">Цветной текст</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="374"/>
+        <location filename="AddPost.py" line="381"/>
         <source>Choose color</source>
-        <translation type="unfinished">Выбрать цвет</translation>
+        <translation type="obsolete">Выбрать цвет</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="402"/>
+        <location filename="AddPost.py" line="411"/>
         <source>Add option</source>
         <translation type="unfinished">Добавить опцию</translation>
     </message>
@@ -168,12 +168,12 @@
         <translation type="obsolete">Вы хотите отправить пост с пустым заголовком?</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="231"/>
+        <location filename="AddPost.py" line="251"/>
         <source>Post is edit</source>
         <translation type="unfinished">Пост редактирован</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="314"/>
+        <location filename="AddPost.py" line="333"/>
         <source>Add html tags</source>
         <translation type="unfinished">Добавить html теги</translation>
     </message>
@@ -183,100 +183,120 @@
         <translation type="unfinished">Тема</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="115"/>
+        <location filename="AddPost.py" line="118"/>
         <source>../data/en/image.png</source>
         <translation type="unfinished">../data/en/image.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="123"/>
+        <location filename="AddPost.py" line="126"/>
         <source>../data/en/add_link.png</source>
         <translation type="unfinished">../data/en/add_link.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="131"/>
+        <location filename="AddPost.py" line="134"/>
         <source>../data/en/add_html.png</source>
         <translation type="unfinished">../data/en/add_html.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="139"/>
+        <location filename="AddPost.py" line="142"/>
         <source>../data/en/options.png</source>
         <translation type="unfinished">../data/en/options.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="151"/>
+        <location filename="AddPost.py" line="171"/>
         <source>../data/en/post_send_to.png</source>
         <translation type="unfinished">../data/en/post_send_to.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="156"/>
+        <location filename="AddPost.py" line="176"/>
         <source>../data/en/send_post.png</source>
         <translation type="unfinished">../data/en/send_post.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="204"/>
+        <location filename="AddPost.py" line="224"/>
         <source>The post is empty!</source>
         <translation type="unfinished">Пост - пустой!!</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="211"/>
+        <location filename="AddPost.py" line="231"/>
         <source>Do you want to send post with empty subject?</source>
         <translation type="unfinished">Вы действительно хотите послать пост без темы?</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="248"/>
+        <location filename="AddPost.py" line="266"/>
         <source>Link to the image (URL)</source>
         <translation type="unfinished">Ссылка на изображение(URL)</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="280"/>
+        <location filename="AddPost.py" line="298"/>
         <source>Link</source>
         <translation type="unfinished">Ссылка</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="412"/>
+        <location filename="AddPost.py" line="421"/>
         <source>Tags (comma separated)</source>
         <translation type="unfinished">Теги (через запятую)</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="435"/>
+        <location filename="AddPost.py" line="444"/>
         <source>Post will be lost! Continue? </source>
         <translation type="unfinished">Пост будет утерян! Продолжить?</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="116"/>
+        <location filename="AddPost.py" line="119"/>
         <source>Add image</source>
         <translation type="unfinished">Изображение</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="132"/>
+        <location filename="AddPost.py" line="135"/>
         <source>HTML</source>
         <translation type="unfinished">HTML</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="140"/>
+        <location filename="AddPost.py" line="143"/>
         <source>Options</source>
         <translation type="unfinished">Опции</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="152"/>
+        <location filename="AddPost.py" line="172"/>
         <source>Send to..</source>
-        <translation type="unfinished">Отправить в ..</translation>
+        <translation type="unfinished">Далее</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="157"/>
+        <location filename="AddPost.py" line="177"/>
         <source>Send</source>
         <translation type="unfinished">Отправить</translation>
     </message>
+    <message>
+        <location filename="AddPost.py" line="150"/>
+        <source>../data/en/undo.png</source>
+        <translation type="unfinished">../data/en/undo.png</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="151"/>
+        <source>Undo</source>
+        <translation type="unfinished">Отмена</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="158"/>
+        <source>../data/en/redo.png</source>
+        <translation type="unfinished">../data/en/redo.png</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="159"/>
+        <source>Redo</source>
+        <translation type="unfinished">Возврат</translation>
+    </message>
 </context>
 <context>
     <name>AddProfileWindow</name>
     <message>
-        <location filename="AddProfile.py" line="49"/>
+        <location filename="AddProfile.py" line="52"/>
         <source>Login</source>
         <translation type="unfinished">Логин</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="51"/>
+        <location filename="AddProfile.py" line="54"/>
         <source>Password</source>
         <translation type="unfinished">Пароль</translation>
     </message>
@@ -296,12 +316,12 @@
         <translation type="obsolete">Да</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="243"/>
+        <location filename="AddProfile.py" line="250"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="184"/>
+        <location filename="AddProfile.py" line="191"/>
         <source>Please, fill all fields!</source>
         <translation type="unfinished">Пожалуйста, заполните все поля!</translation>
     </message>
@@ -311,80 +331,80 @@
         <translation type="obsolete">Вы действительно хотите удалить аккаунт?</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="244"/>
+        <location filename="AddProfile.py" line="251"/>
         <source>Account was deleted</source>
         <translation type="unfinished">Аккаунт удален</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="229"/>
+        <location filename="AddProfile.py" line="236"/>
         <source>Do you really want to delete account?</source>
         <translation type="unfinished">Вы действительно хотите удалить аккаунт?</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="64"/>
+        <location filename="AddProfile.py" line="67"/>
         <source>Blog Service</source>
         <translation type="unfinished">Блог сервис</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="109"/>
+        <location filename="AddProfile.py" line="114"/>
         <source>../data/en/remove_profile.png</source>
-        <translation type="unfinished">../data/en/remove_profile.png</translation>
+        <translation type="obsolete">../data/en/remove_profile.png</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="115"/>
+        <location filename="AddProfile.py" line="122"/>
         <source>../data/en/change_profile_ok.png</source>
-        <translation type="unfinished">../data/en/change_profile_ok_en.png</translation>
+        <translation type="unfinished">../data/en/change_profile_ok.png</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="118"/>
+        <location filename="AddProfile.py" line="125"/>
         <source>../data/en/add_profile.png</source>
         <translation type="unfinished">../data/en/add_profile.png</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="110"/>
+        <location filename="AddProfile.py" line="117"/>
         <source>Delete account</source>
-        <translation type="unfinished">Удалить аккаунт</translation>
+        <translation type="unfinished">Удалить</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="116"/>
+        <location filename="AddProfile.py" line="123"/>
         <source>OK</source>
         <translation type="unfinished">OK</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="119"/>
-        <source>Add profile</source>
-        <translation type="unfinished">Добавить аккаунт</translation>
+        <location filename="AddProfile.py" line="126"/>
+        <source>Add account</source>
+        <translation type="unfinished">Добавить</translation>
     </message>
 </context>
 <context>
     <name>HomePage</name>
     <message>
-        <location filename="HomePage.py" line="94"/>
+        <location filename="HomePage.py" line="100"/>
         <source>&lt;h2&gt;Personal info:&lt;/h2&gt;&lt;br&gt;</source>
         <translation type="unfinished">&lt;h2&gt;Персональная информация:&lt;/h2&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="96"/>
+        <location filename="HomePage.py" line="102"/>
         <source>&lt;div&gt;Nick: &lt;b&gt;</source>
         <translation type="unfinished">&lt;div&gt;Имя: &lt;b&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="100"/>
+        <location filename="HomePage.py" line="106"/>
         <source>&lt;/b&gt;&lt;/div&gt;&lt;br&gt;</source>
         <translation type="unfinished">&lt;/b&gt;&lt;/div&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="99"/>
+        <location filename="HomePage.py" line="105"/>
         <source>&lt;div&gt;Birthday: &lt;b&gt;</source>
         <translation type="unfinished">&lt;div&gt;День рождения: &lt;b&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="102"/>
+        <location filename="HomePage.py" line="108"/>
         <source>&lt;div&gt;City: &lt;b&gt;</source>
         <translation type="unfinished">&lt;div&gt;Город: &lt;b&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="103"/>
+        <location filename="HomePage.py" line="109"/>
         <source>&lt;/b&gt;&lt;/div&gt;</source>
         <translation type="unfinished">&lt;/b&gt;&lt;/div&gt;</translation>
     </message>
@@ -394,22 +414,22 @@
         <translation type="obsolete">&lt;div&gt;Сервис: &lt;b&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="106"/>
+        <location filename="HomePage.py" line="112"/>
         <source>&lt;b&gt;&lt;br&gt;&lt;/div&gt;&lt;br&gt;</source>
         <translation type="unfinished">&lt;b&gt;&lt;br&gt;&lt;/div&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="141"/>
+        <location filename="HomePage.py" line="147"/>
         <source>Photo</source>
         <translation type="unfinished">Фото</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="170"/>
+        <location filename="HomePage.py" line="176"/>
         <source>&amp;Add post</source>
         <translation type="unfinished">Добавить пост</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="171"/>
+        <location filename="HomePage.py" line="177"/>
         <source>&amp;My posts</source>
         <translation type="unfinished">Мои посты</translation>
     </message>
@@ -419,27 +439,27 @@
         <translation type="obsolete">Посты друзей</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="105"/>
+        <location filename="HomePage.py" line="111"/>
         <source>&lt;div&gt;Blog service: &lt;b&gt;</source>
         <translation type="unfinished">&lt;div&gt;Блог сервис: &lt;b&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="172"/>
+        <location filename="HomePage.py" line="178"/>
         <source>&amp;Friends&apos; posts</source>
         <translation type="unfinished">&amp;Посты друзей</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="174"/>
+        <location filename="HomePage.py" line="180"/>
         <source>../data/en/add_post.png</source>
         <translation type="unfinished">../data/en/add_post.png</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="175"/>
+        <location filename="HomePage.py" line="181"/>
         <source>../data/en/my_posts.png</source>
         <translation type="unfinished">../data/en/my_posts.png</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="176"/>
+        <location filename="HomePage.py" line="182"/>
         <source>../data/en/friends_posts.png</source>
         <translation type="unfinished">../data/en/friends_posts.png</translation>
     </message>
@@ -447,7 +467,7 @@
 <context>
     <name>ListFriendsPosts</name>
     <message>
-        <location filename="ListFriendsPosts.py" line="47"/>
+        <location filename="ListFriendsPosts.py" line="48"/>
         <source>Refresh</source>
         <translation type="unfinished">Обновить</translation>
     </message>
@@ -455,12 +475,12 @@
 <context>
     <name>ListMyPosts</name>
     <message>
-        <location filename="ListMyPosts.py" line="125"/>
+        <location filename="ListMyPosts.py" line="130"/>
         <source>Refresh</source>
         <translation type="unfinished">Обновить</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="63"/>
+        <location filename="ListMyPosts.py" line="66"/>
         <source>Don&apos;t show this message again</source>
         <translation type="unfinished">Больше не показывать это сообщение</translation>
     </message>
@@ -470,7 +490,7 @@
         <translation type="obsolete">Нажмите кнопку для обновления постов</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="81"/>
+        <location filename="ListMyPosts.py" line="84"/>
         <source>no subject</source>
         <translation type="unfinished">без темы</translation>
     </message>
@@ -485,17 +505,17 @@
         <translation type="obsolete">Удалить</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="179"/>
+        <location filename="ListMyPosts.py" line="184"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="159"/>
+        <location filename="ListMyPosts.py" line="164"/>
         <source>Do you really want to delete post?</source>
         <translation type="unfinished">Вы действительно хотите удалить пост?</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="180"/>
+        <location filename="ListMyPosts.py" line="185"/>
         <source>Please, choose messages to delete!</source>
         <translation type="unfinished">Пожалуйста, выберите удаляемые сообщения</translation>
     </message>
@@ -505,7 +525,7 @@
         <translation type="obsolete">Подождите ...</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="193"/>
+        <location filename="ListMyPosts.py" line="198"/>
         <source>Cancel</source>
         <translation type="unfinished">Отмена</translation>
     </message>
@@ -515,37 +535,37 @@
         <translation type="obsolete">Получение данных ...</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="62"/>
+        <location filename="ListMyPosts.py" line="65"/>
         <source>Refresh message</source>
         <translation type="unfinished">Обновить сообщение</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="64"/>
+        <location filename="ListMyPosts.py" line="67"/>
         <source>Press &quot;Refresh&quot; to update post</source>
         <translation type="unfinished">Нажмите &quot;Обновить&quot; для обновления постов</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="192"/>
+        <location filename="ListMyPosts.py" line="197"/>
         <source>Operation is in progress.</source>
         <translation type="unfinished">Операция выполняется</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="194"/>
+        <location filename="ListMyPosts.py" line="199"/>
         <source>Receiving data...</source>
         <translation type="unfinished">Получение данных..</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="124"/>
+        <location filename="ListMyPosts.py" line="129"/>
         <source>../data/en/refresh.png</source>
         <translation type="unfinished">../data/en/refresh.png</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="133"/>
+        <location filename="ListMyPosts.py" line="138"/>
         <source>../data/en/post_delete.png</source>
         <translation type="unfinished">../data/en/post_delete.png</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="134"/>
+        <location filename="ListMyPosts.py" line="139"/>
         <source>Delete</source>
         <translation type="unfinished">Удалить</translation>
     </message>
@@ -553,7 +573,7 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="MainWindow.py" line="102"/>
+        <location filename="MainWindow.py" line="149"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
@@ -568,12 +588,12 @@
         <translation type="obsolete">Редактирование аккаунтов</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="91"/>
+        <location filename="MainWindow.py" line="82"/>
         <source>About Scribo</source>
         <translation type="unfinished">О программе</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="113"/>
+        <location filename="MainWindow.py" line="104"/>
         <source>Ctrl+N</source>
         <translation type="unfinished">Ctrl+N</translation>
     </message>
@@ -583,17 +603,17 @@
         <translation type="obsolete">Выход</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="123"/>
+        <location filename="MainWindow.py" line="112"/>
         <source>Ctrl+Q</source>
         <translation type="unfinished">Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="132"/>
+        <location filename="MainWindow.py" line="120"/>
         <source>&amp;About</source>
         <translation type="unfinished">О программе</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="143"/>
+        <location filename="MainWindow.py" line="130"/>
         <source>&amp;Menu</source>
         <translation type="unfinished">Меню</translation>
     </message>
@@ -608,7 +628,7 @@
         <translation type="obsolete">&amp;Редактирование аккаунтов</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="122"/>
+        <location filename="MainWindow.py" line="111"/>
         <source>E&amp;xit</source>
         <translation type="unfinished">&amp;Выход</translation>
     </message>
@@ -623,26 +643,31 @@
         <translation type="unfinished">&amp;Редактирование аккаунтов</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="93"/>
+        <location filename="MainWindow.py" line="84"/>
         <source>A mobile multiblog client. 
  Version: </source>
         <translation type="unfinished">Мобильный мультиблоговый клиент. Версия:</translation>
     </message>
+    <message>
+        <location filename="MainWindow.py" line="149"/>
+        <source>Do you really want to quit?</source>
+        <translation type="unfinished">Вы действительно хотите выйти?</translation>
+    </message>
 </context>
 <context>
     <name>MyModel</name>
     <message>
-        <location filename="TreeMessage.py" line="116"/>
+        <location filename="TreeMessage.py" line="123"/>
         <source>Author</source>
         <translation type="unfinished">Автор</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="117"/>
+        <location filename="TreeMessage.py" line="124"/>
         <source>Date</source>
         <translation type="unfinished">Дата</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="118"/>
+        <location filename="TreeMessage.py" line="125"/>
         <source>Title</source>
         <translation type="unfinished">Заголовок</translation>
     </message>
@@ -652,7 +677,7 @@
     <message>
         <location filename="RepeatPost.py" line="40"/>
         <source>Please, choose accounts and groups for sending the post</source>
-        <translation type="obsolete">Пожалуйста, выберите аккаунты или группы для отправки поста</translation>
+        <translation type="obsolete">Выберите аккаунты или группы для отправки поста</translation>
     </message>
     <message>
         <location filename="RepeatPost.py" line="58"/>
@@ -660,52 +685,52 @@
         <translation type="obsolete">Отправить</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="74"/>
+        <location filename="RepeatPost.py" line="78"/>
         <source>Service</source>
         <translation type="unfinished">Сервис</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="75"/>
+        <location filename="RepeatPost.py" line="79"/>
         <source>Login</source>
         <translation type="unfinished">Логин</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="187"/>
+        <location filename="RepeatPost.py" line="193"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="151"/>
+        <location filename="RepeatPost.py" line="156"/>
         <source>Please, choose subitem for sending</source>
         <translation type="unfinished">Пожалуйста, выберите подпункт для отправки</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="172"/>
+        <location filename="RepeatPost.py" line="177"/>
         <source>Please, choose accounts or groups for sending</source>
-        <translation type="unfinished">Пожалуйста, выберите аккаунты или группы для отправки</translation>
+        <translation type="unfinished">Выберите аккаунты или группы для отправки</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="179"/>
+        <location filename="RepeatPost.py" line="184"/>
         <source>Post was sent</source>
         <translation type="unfinished">Пост отправлен</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="40"/>
+        <location filename="RepeatPost.py" line="43"/>
         <source>Select accounts and groups for sending</source>
         <translation type="unfinished">Пожалуйста, выберите аккаунты или группы для отправки</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="60"/>
+        <location filename="RepeatPost.py" line="64"/>
         <source>../data/en/send_post.png</source>
         <translation type="unfinished">../data/en/send_post.png</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="61"/>
+        <location filename="RepeatPost.py" line="65"/>
         <source>Send</source>
         <translation type="unfinished">Отправить</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="189"/>
+        <location filename="RepeatPost.py" line="195"/>
         <source>Post will be lost! Continue? </source>
         <translation type="unfinished">Пост будет утерян! Продолжить?</translation>
     </message>
@@ -713,12 +738,12 @@
 <context>
     <name>StartPage</name>
     <message>
-        <location filename="StartPage.py" line="43"/>
+        <location filename="StartPage.py" line="45"/>
         <source>Login</source>
         <translation type="unfinished">Логин</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="45"/>
+        <location filename="StartPage.py" line="47"/>
         <source>Password</source>
         <translation type="unfinished">Пароль</translation>
     </message>
@@ -728,17 +753,17 @@
         <translation type="obsolete">Сервис</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="60"/>
+        <location filename="StartPage.py" line="62"/>
         <source>Go</source>
         <translation type="unfinished">Зайти</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="101"/>
+        <location filename="StartPage.py" line="106"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="102"/>
+        <location filename="StartPage.py" line="107"/>
         <source>Please, fill all fields!</source>
         <translation type="unfinished">Пожалуйста, заполните все поля!</translation>
     </message>
@@ -748,17 +773,17 @@
         <translation type="obsolete">Добро пожаловать в Scribo!</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="158"/>
+        <location filename="StartPage.py" line="162"/>
         <source>../data/Scribo.png</source>
         <translation type="unfinished">../data/Scribo.png</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="47"/>
+        <location filename="StartPage.py" line="49"/>
         <source>Blog service</source>
         <translation type="unfinished">Блог сервис</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="156"/>
+        <location filename="StartPage.py" line="160"/>
         <source>&lt;i&gt;Welcome to Scribo,&lt;br/&gt; mobile multiblog client!&lt;/i&gt;</source>
         <translation type="unfinished">&lt;i&gt;Добро пожаловать в Скрибо,&lt;br/&gt;мобильный мультиблоговый&lt;br/&gt; клиент!&lt;/i&gt;</translation>
     </message>
@@ -778,17 +803,17 @@
     <message>
         <location filename="ToolbarWindow.py" line="29"/>
         <source>../data/en/back.png</source>
-        <translation type="obsolete">../data/ru/back_ru.png</translation>
+        <translation type="obsolete">../data/en/back.png</translation>
     </message>
     <message>
         <location filename="ToolbarWindow.py" line="35"/>
         <source>../data/en/home.png</source>
-        <translation type="obsolete">../data/ru/home_ru.png</translation>
+        <translation type="obsolete">../data/en/home.png</translation>
     </message>
     <message>
         <location filename="ToolbarWindow.py" line="50"/>
         <source>Back</source>
-        <translation type="unfinished">Назад</translation>
+        <translation type="obsolete">Назад</translation>
     </message>
     <message>
         <location filename="ToolbarWindow.py" line="58"/>
@@ -804,12 +829,12 @@
         <translation type="obsolete">&amp;Обновить</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="75"/>
+        <location filename="TreeMessage.py" line="81"/>
         <source>../data/en/refresh.png</source>
         <translation type="unfinished">../data/en/refresh.png</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="76"/>
+        <location filename="TreeMessage.py" line="82"/>
         <source>Refresh</source>
         <translation type="unfinished">Обновить</translation>
     </message>
@@ -817,7 +842,7 @@
 <context>
     <name>ViewMessage</name>
     <message>
-        <location filename="ViewMessage.py" line="110"/>
+        <location filename="ViewMessage.py" line="113"/>
         <source>no subject</source>
         <translation type="unfinished">без темы</translation>
     </message>
@@ -864,7 +889,7 @@
     <message>
         <location filename="ViewMessage.py" line="221"/>
         <source>&amp;Comment tree</source>
-        <translation type="obsolete">Дерево комментариев</translation>
+        <translation type="obsolete">Комментарии</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="121"/>
@@ -896,45 +921,65 @@
     <message>
         <location filename="ViewMessage.py" line="239"/>
         <source>&amp;Tree comments</source>
-        <translation type="obsolete">&amp;Дерево комментариев</translation>
+        <translation type="obsolete">&amp;Комментарии</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="217"/>
+        <location filename="ViewMessage.py" line="228"/>
         <source>../data/en/post_prev.png</source>
         <translation type="unfinished">../data/en/post_prev.png</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="225"/>
+        <location filename="ViewMessage.py" line="236"/>
         <source>../data/en/post_next.png</source>
         <translation type="unfinished">../data/en/post_next.png</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="242"/>
+        <location filename="ViewMessage.py" line="271"/>
         <source>../data/en/post_edit.png</source>
         <translation type="unfinished">../data/en/post_edit.png</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="218"/>
+        <location filename="ViewMessage.py" line="229"/>
         <source>Previous</source>
         <translation type="unfinished">Пред.</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="226"/>
+        <location filename="ViewMessage.py" line="237"/>
         <source>Next</source>
         <translation type="unfinished">След.</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="243"/>
+        <location filename="ViewMessage.py" line="272"/>
         <source>Edit</source>
         <translation type="unfinished">Изменить</translation>
     </message>
+    <message>
+        <location filename="ViewMessage.py" line="244"/>
+        <source>../data/en/decrease_font.png</source>
+        <translation type="unfinished">../data/en/decrease_font.png</translation>
+    </message>
+    <message>
+        <location filename="ViewMessage.py" line="245"/>
+        <source>Decrease</source>
+        <translation type="unfinished">Уменьшить</translation>
+    </message>
+    <message>
+        <location filename="ViewMessage.py" line="252"/>
+        <source>../data/en/increase_font.png</source>
+        <translation type="unfinished">../data/en/increase_font.png</translation>
+    </message>
+    <message>
+        <location filename="ViewMessage.py" line="253"/>
+        <source>Increase</source>
+        <translation type="unfinished">Увеличить</translation>
+    </message>
 </context>
 <context>
     <name>main_window</name>
     <message>
         <location filename="ToolbarWindow.py" line="49"/>
         <source>../data/en/back.png</source>
-        <translation type="unfinished">../data/en/back.png</translation>
+        <translation type="obsolete">../data/en/back.png</translation>
     </message>
     <message>
         <location filename="ToolbarWindow.py" line="57"/>
