@@ -13,9 +13,11 @@ sys.path.append("../ldm")
 sys.path.append("../ui")
 sys.path.append("../services")
 
-from SysTest import *
-from SysFT import *
-from BDTest import *
+import test.SysTest
+import test.SysFT
+import test.BDTest
+
+
 
 
 __author__ = "Kirill Germanov <kgermano@cs.karelia.ru>"
@@ -24,7 +26,7 @@ __date__ = "$Date: 2010/02/14 $"
 __copyright__ = ""
 __license__ = "GPLv2"
 
-class AddPostTest:
+class ALLTESTS:
     """
     Class with test method for SendPost module
     @version  1.0
@@ -37,3 +39,5 @@ class AddPostTest:
         @return
         """
         print "Run~!"
+
+
