@@ -11,8 +11,9 @@
 from PyQt4 import QtCore
 from PyQt4 import QtGui
 
-from MainWindow import main_window
+#from HomePage import home_page
 from ToolbarWindow import ToolbarWindow
+from MainWindow import *
 from ldm.Profile import *
 from ldm.Account import *
 from services.LivejAccount import *
@@ -23,7 +24,7 @@ __date__ = "$Date: 2009/12/11 $"
 __copyright__ = ""
 __license__ = "GPLv2"
 
-class AddPostWindow(QtGui.QWidget):
+class AddPostWindow(MainWindow):
     """
     class for draw add post window
     @version  1.0
@@ -40,21 +41,32 @@ class AddPostWindow(QtGui.QWidget):
         self.msg = msg
         self.is_change = False
         self.start_text = ""
-        QtGui.QWidget.__init__(self, parent.centralWidget())
-
+        self.plain_text = ""
+        self.sending_post = False
+        
+        super(AddPostWindow, self).__init__(parent)
+        self.parent = parent
+        self.centr_widg = QtGui.QWidget(parent)
+        
         self.vbox_add = QtGui.QVBoxLayout()
         self.hbox_all = QtGui.QHBoxLayout()
-
-        self.create_actions()
-        first_toolbar = self.create_toolbar()
-        second_toolbar = self.create_toolbar_second()
+        self.hbox_title = QtGui.QHBoxLayout()        
 
         title_label = QtGui.QLabel(self.tr("Subject"), self)
         title_label.setAlignment(QtCore.Qt.AlignLeft)
 
         self.text_edit = QtGui.QTextEdit(self)
+        self.text_edit.setReadOnly(False)
+        self.text_edit.setAutoFormatting(QtGui.QTextEdit.AutoNone)
+        self.text_edit.setTextInteractionFlags(QtCore.Qt.TextEditorInteraction)
         self.title_edit = QtGui.QLineEdit(self)
         self.title_edit.setMaxLength(100)
+
+        self.combo_view = QtGui.QComboBox(self.centr_widg)
+        self.combo_view.addItem(self.tr("Edit"))
+        self.combo_view.addItem(self.tr("Preview"))
+        self.connect(self.combo_view,QtCore.SIGNAL("currentIndexChanged(int)"),
+                         self.reload_edit)
         if msg:
             self.text_edit.insertPlainText(msg.text)
             self.start_text = msg.text
@@ -64,31 +76,39 @@ class AddPostWindow(QtGui.QWidget):
             self.title_edit.setText(title)
         self.title_edit.setFocus()
 
+        self.connect(self.text_edit, QtCore.SIGNAL("undoAvailable(bool)"),self.undo_available)
+        self.connect(self.text_edit, QtCore.SIGNAL("redoAvailable(bool)"),self.redo_available)
+        self.create_actions()
+        first_toolbar = self.create_toolbar()
+        second_toolbar = self.create_toolbar_second()
+        self.undo_act.setDisabled(True)
+        self.redo_act.setDisabled(True)
+
+        self.hbox_title.addWidget(title_label)
+        self.hbox_title.addWidget(self.combo_view)
         self.hbox_all.addWidget(first_toolbar)
         self.hbox_all.addSpacing(5)
-        self.vbox_add.addWidget(title_label)
+        self.vbox_add.addLayout(self.hbox_title)
         self.vbox_add.addWidget(self.title_edit)
         self.vbox_add.addWidget(self.text_edit)
 
         self.hbox_all.addLayout(self.vbox_add)
         self.hbox_all.addSpacing(5)
         self.hbox_all.addWidget(second_toolbar)
-        self.setLayout(self.hbox_all)
 
+        self.centr_widg.setLayout(self.hbox_all)
+        self.setCentralWidget(self.centr_widg)
+        self.show()
 
     def create_toolbar(self):
         """
         create profile for "add profile" window
         @return
         """
-        file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
+        file_tool_bar = ToolbarWindow(parent=self.centr_widg)
         file_tool_bar.addWidget(self.send_act)
-        self.disconnect(file_tool_bar.back_act, QtCore.SIGNAL("clicked()"),
-                     main_window.back_window)
-        self.connect(file_tool_bar.back_act, QtCore.SIGNAL("clicked()"),
-                     self.back_window)
-        self.disconnect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
-                     main_window.home_window)
+        file_tool_bar.addWidget(self.undo_act)
+        file_tool_bar.addWidget(self.redo_act)
         self.connect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
                      self.home_window)
         return file_tool_bar
@@ -98,7 +118,7 @@ class AddPostWindow(QtGui.QWidget):
         create profile for "add profile" window
         @return
         """
-        second_tool_bar = ToolbarWindow(parent=main_window.centralWidget(), right=True)
+        second_tool_bar = ToolbarWindow(parent=self.centr_widg, right=True)
         second_tool_bar.addWidget(self.pict_act)
         second_tool_bar.addWidget(self.link_act)
         second_tool_bar.addWidget(self.other_act)
@@ -111,7 +131,7 @@ class AddPostWindow(QtGui.QWidget):
         @return
         """
 
-        self.pict_act = QtGui.QToolButton(self)
+        self.pict_act = QtGui.QToolButton(self.centr_widg)
         self.pict_act.setIcon(QtGui.QIcon(self.tr("../data/en/image.png")))
         self.pict_act.setText(self.tr("Add image"))
         self.pict_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
@@ -119,7 +139,7 @@ class AddPostWindow(QtGui.QWidget):
         self.connect(self.pict_act, QtCore.SIGNAL("clicked()"),
                      self.pict_post)
 
-        self.link_act = QtGui.QToolButton(self)
+        self.link_act = QtGui.QToolButton(self.centr_widg)
         self.link_act.setIcon(QtGui.QIcon(self.tr("../data/en/add_link.png")))
         self.link_act.setText(self.tr("Add link"))
         self.link_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
@@ -127,7 +147,7 @@ class AddPostWindow(QtGui.QWidget):
         self.connect(self.link_act, QtCore.SIGNAL("clicked()"),
                      self.link_post)
 
-        self.other_act = QtGui.QToolButton(self)
+        self.other_act = QtGui.QToolButton(self.centr_widg)
         self.other_act.setIcon(QtGui.QIcon(self.tr("../data/en/add_html.png")))
         self.other_act.setText(self.tr("HTML"))
         self.other_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
@@ -135,7 +155,7 @@ class AddPostWindow(QtGui.QWidget):
         self.connect(self.other_act, QtCore.SIGNAL("clicked()"),
                      self.other_post)
 
-        self.option_act = QtGui.QToolButton(self)
+        self.option_act = QtGui.QToolButton(self.centr_widg)
         self.option_act.setIcon(QtGui.QIcon(self.tr("../data/en/options.png")))
         self.option_act.setText(self.tr("Options"))
         self.option_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
@@ -143,6 +163,23 @@ class AddPostWindow(QtGui.QWidget):
         self.connect(self.option_act, QtCore.SIGNAL("clicked()"),
                      self.option_post)
 
+        self.undo_act = QtGui.QToolButton(self.centr_widg)
+        self.undo_act.setIcon(QtGui.QIcon(self.tr("../data/en/undo.png")))
+        self.undo_act.setText(self.tr("Undo"))
+        self.undo_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.undo_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.undo_act, QtCore.SIGNAL("clicked()"),
+                     self.text_edit.undo)
+
+        self.redo_act = QtGui.QToolButton(self.centr_widg)
+        self.redo_act.setIcon(QtGui.QIcon(self.tr("../data/en/redo.png")))
+        self.redo_act.setText(self.tr("Redo"))
+        self.redo_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.redo_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.redo_act, QtCore.SIGNAL("clicked()"),
+                     self.text_edit.redo)
+        
+
 
         self.send_act = QtGui.QToolButton(self)
 
@@ -166,7 +203,12 @@ class AddPostWindow(QtGui.QWidget):
         handler for button OK
         @return
         """
-        text_post = QtCore.QString(unicode(self.text_edit.toPlainText())).trimmed()
+        if self.combo_view.currentIndex() == 1:
+            text_post =self.plain_text
+            #QtCore.QString(unicode(self.text_edit.toHtml())).trimmed()
+        else:
+            text_post = QtCore.QString(unicode(self.text_edit.toPlainText())).trimmed()
+
         if (text_post == ""):
             ret = QtGui.QMessageBox.critical(self, self.tr("Scribo"),
                                self.tr("The post is empty!"),
@@ -189,8 +231,8 @@ class AddPostWindow(QtGui.QWidget):
             mes.tags = unicode(self.tags)
 
         from ui.RepeatPost import RepeatPost
-        rep_post = RepeatPost(main_window, mes)
-        main_window.push_window(rep_post)
+        rep_post = RepeatPost(self, mes)
+        
 
 
     def edit_post(self):
@@ -198,7 +240,12 @@ class AddPostWindow(QtGui.QWidget):
         handler for button OK
         @return
         """
-        text_post = QtCore.QString(unicode(self.text_edit.toPlainText())).trimmed()
+        if self.combo_view.currentIndex() == 1:
+            text_post = self.plain_text
+            #QtCore.QString(unicode(self.text_edit.toHtml())).trimmed()
+        else:
+            text_post = QtCore.QString(unicode(self.text_edit.toPlainText())).trimmed()
+
         if text_post == "":
             ret = QtGui.QMessageBox.critical(self, self.tr("Scribo"),
                                self.tr("The post is empty!"),
@@ -225,13 +272,13 @@ class AddPostWindow(QtGui.QWidget):
         try:
             res = author.edit_post(mes)
         except WarningExc, exc:
-            main_window.show_warning(exc)
+            super(AddPost, self).show_warning(exc)
         else:
             ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                                 self.tr("Post is edit"),
                                                 QtGui.QMessageBox.Yes)
         mes.del_msg_tree()
-        main_window.home_window()
+        super(AddPost, self).home_window()
 
 
     def pict_post(self):
@@ -240,8 +287,6 @@ class AddPostWindow(QtGui.QWidget):
         @param 
         @return
         """
-
-
         msg = QtGui.QMessageBox()
         uri_edit = QtGui.QLineEdit(msg)
         msg.setWindowTitle(self.tr("Add picture"))
@@ -258,10 +303,12 @@ class AddPostWindow(QtGui.QWidget):
 
         if msg.clickedButton() == link_button:
             link = uri_edit.text()
+            text = self.text_edit.textCursor().selectedText()
+
             if QtCore.QString(link).contains("http://", QtCore.Qt.CaseInsensitive):
-                self.text_edit.insertPlainText("<img src=\"" + link + "\"/>")
+                self.text_edit.insertPlainText("<img src=\"" + link + "\" title = \""+ text+"\"/>")
             else:
-                self.text_edit.insertPlainText("<img src=\"http://" + link + "\"/>")
+                self.text_edit.insertPlainText("<img src=\"http://" + link + "\" title = \""+ text+ "\"/>")
 
 
     def link_post(self):
@@ -270,8 +317,6 @@ class AddPostWindow(QtGui.QWidget):
         @param
         @return 
         """
-
-
         msg = QtGui.QMessageBox()
         msg.setWindowTitle(self.tr("Add link"))
         uri_edit = QtGui.QLineEdit(msg)
@@ -291,10 +336,11 @@ class AddPostWindow(QtGui.QWidget):
             return
         if msg.clickedButton() == link_button:
             link = uri_edit.text()
+            text_link = self.text_edit.textCursor().selectedText() 
             if QtCore.QString(link).contains("http://", QtCore.Qt.CaseInsensitive):
-                self.text_edit.insertPlainText("<a href=\"" + link + "\"></a>")
+                self.text_edit.insertPlainText("<a href=\"" + link + "\">" + text_link + "</a>")
             else:
-                self.text_edit.insertPlainText("<a href=\"http://" + link + "\"></a>")
+                self.text_edit.insertPlainText("<a href=\"http://" + link + "\">" + text_link + "</a>")
 
     def other_post(self):
         '''
@@ -304,7 +350,7 @@ class AddPostWindow(QtGui.QWidget):
         #if start <> -1:
             #text = self.text_edit.selectedText()
         self.dial = QtGui.QMessageBox()
-
+        
         but_box = QtGui.QDialogButtonBox()
         but_box2 = QtGui.QDialogButtonBox()
 
@@ -346,12 +392,12 @@ class AddPostWindow(QtGui.QWidget):
             return
 
     def html_click(self, button):
-        text = ""
+        text = self.text_edit.textCursor().selectedText()
 
         if button == self.bold_button:
-            self.text_edit.insertPlainText("<b>" + text + "</b>")
+            self.text_edit.insertPlainText("<span style=\"font-weight:bold\">" + text + "</span>")
         elif button == self.italic_button:
-            self.text_edit.insertPlainText("<i>" + text + "</i>")
+            self.text_edit.insertPlainText("<span style=\"font-style:italic\">" + text + "</span>")
         elif button == self.center_button:
             self.text_edit.insertPlainText("<div style=\"text-align:center\">"
                                       + text + "</div>")
@@ -365,27 +411,17 @@ class AddPostWindow(QtGui.QWidget):
             self.text_edit.insertPlainText("<div style=\"text-align:justify\">"
                                       + text + "</div>")
         elif button == self.color_button:
-            color_edit = QtGui.QLineEdit()
+            link = self.text_edit.textCursor().selectedText()
 
-            msg2 = QtGui.QMessageBox()
-            title = QtGui.QLabel(self.tr("Color text"), msg2)
-            msg2.layout().addWidget(title, 0, 0)
-            msg2.layout().addWidget(color_edit, 1, 0)
-            color_dial_but = msg2.addButton(self.tr("Choose color"),
-                                            QtGui.QMessageBox.RejectRole)
-            msg2.exec_()
-
-            if msg2.clickedButton() == color_dial_but:
-                link = color_edit.text()
-                col = QtGui.QColorDialog.getColor()
-                if col.isValid():
-                    red = QtCore.QString().number(col.red(), 16).toUpper()
-                    green = QtCore.QString().number(col.green(), 16).toUpper()
-                    blue = QtCore.QString().number(col.blue(), 16).toUpper()
-                    color = red + green + blue
-                    self.text_edit.insertPlainText("<font color=\"#"
-                                               + color + "\">"
-                                               + link + "</font>")
+            col = QtGui.QColorDialog.getColor()
+            if col.isValid():
+                red = QtCore.QString().number(col.red(), 16).toUpper()
+                green = QtCore.QString().number(col.green(), 16).toUpper()
+                blue = QtCore.QString().number(col.blue(), 16).toUpper()
+                color = red + green + blue
+                self.text_edit.insertPlainText("<span style=\"color:#"
+                                           + color + "\">"
+                                           + link + "</span>")
         else:
     	    return
         self.dial.reject()
@@ -439,15 +475,43 @@ class AddPostWindow(QtGui.QWidget):
             res = QtGui.QMessageBox.Yes
         return res
 
-    def back_window(self):
+    def undo_available(self, undo):
+        if undo:
+            self.undo_act.setDisabled(False)
+        else:
+            self.undo_act.setDisabled(True)
+
+    def redo_available(self, redo):
+        if redo:
+            self.redo_act.setDisabled(False)
+        else:
+            self.redo_act.setDisabled(True)
+
+    def reload_edit(self, number):
+        """                                                                                                                                                 
+        reload text edit                                                                                                                            
+        @param number = index of selected items                                                                                                             
+        @return                                                                                                                                             
+        """
+        if number == 1:
+            self.text_edit.setReadOnly(True)
+            self.plain_text = self.text_edit.toPlainText()
+            self.text_edit.setHtml(self.plain_text)
+        else:
+            self.text_edit.setReadOnly(False)
+            self.text_edit.setPlainText(self.plain_text)
+                
+    
+    def closeEvent(self, event):
         """
         check post on changing event
         """
-        ret = self.text_changed()
-        if (ret == QtGui.QMessageBox.No):
+        if not self.sending_post:
+            ret = self.text_changed()
+            if (ret == QtGui.QMessageBox.No):
                 return
-        main_window.back_window()
-
+        event.accept()
+    
     def home_window(self):
         """
         check post on changing event
@@ -455,4 +519,4 @@ class AddPostWindow(QtGui.QWidget):
         ret = self.text_changed()
         if (ret == QtGui.QMessageBox.No):
                 return
-        main_window.home_window()
+        super(AddPostWindow, self).home_window()
