@@ -4,7 +4,7 @@
   File is a part of Scribo Project
   Module implements add profile window from UI
   @author: Zaiceva Diana <zaiceva@cs.karelia.ru>
-  @date: 11.12.2009
+  @date: 23.06.2010
 """
 import sys
 
@@ -17,10 +17,10 @@ from services.Dispatcher import dispatcher
 
 from ToolbarWindow import ToolbarWindow
 from StartPage import StartPage
-from MainWindow import main_window
+from MainWindow import *
 __author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
-__version__ = "$Revision: 0.1 $"
-__date__ = "$Date: 2009/12/11 $"
+__version__ = "$Revision: 0.2 $"
+__date__ = "$Date: 2010/06/23 $"
 __copyright__ = ""
 __license__ = "GPLv2"
 
@@ -30,7 +30,6 @@ class AddProfileWindow(StartPage):
     class for draw profile window
     @version  1.0
     @author  Zaiceva Diana <zaiceva@cs.karelia.ru>
-    @todo  auth_check
     """
     def __init__(self, parent=None, default=None):
         """
@@ -38,20 +37,24 @@ class AddProfileWindow(StartPage):
         default = default account (for managing profile) or None (for adding profile) 
         @return
         """
-        QtGui.QWidget.__init__(self, parent.centralWidget())
+        super(StartPage, self).__init__(parent)
+        #QtGui.QWidget.__init__(self, parent.centralWidget())
         #StartPage.__init__(self, main_window)
+        
+        self.centr_widg = QtGui.QWidget(self)
         self.accounts2 = []
         self.default = default
         self.create_actions()
+        self.parent = parent
         toolbar = self.create_toolbar()
         self.hbox_add = QtGui.QHBoxLayout()
 
-        login_label = QtGui.QLabel(self.tr("Login"), self)
+        login_label = QtGui.QLabel(self.tr("Login"), self.centr_widg)
         login_label.setAlignment(QtCore.Qt.AlignRight)
-        pasw_label = QtGui.QLabel(self.tr("Password"), self)
+        pasw_label = QtGui.QLabel(self.tr("Password"), self.centr_widg)
         pasw_label.setAlignment(QtCore.Qt.AlignRight)
-        self.login_edit = QtGui.QLineEdit(self)
-        self.pasw_edit = QtGui.QLineEdit(self)
+        self.login_edit = QtGui.QLineEdit(self.centr_widg)
+        self.pasw_edit = QtGui.QLineEdit(self.centr_widg)
         self.pasw_edit.setEchoMode(QtGui.QLineEdit.Password)
         self.login_edit.setFocus()
         self.serv_combo = self.create_list_acc(self.default)
@@ -61,14 +64,14 @@ class AddProfileWindow(StartPage):
         grid.addWidget(self.login_edit, 0, 1, 1, 4, QtCore.Qt.AlignLeft)
         grid.addWidget(pasw_label, 1, 0)
         grid.addWidget(self.pasw_edit, 1, 1, 1, 4, QtCore.Qt.AlignLeft)
-        service_label = QtGui.QLabel(self.tr("Blog Service"), self)
+        service_label = QtGui.QLabel(self.tr("Blog Service"), self.centr_widg)
         service_label.setAlignment(QtCore.Qt.AlignRight)
         grid.addWidget(service_label, 2, 0)
         if default:
             self.login_edit.setText(self.default.username)
             self.pasw_edit.setText(self.default.passwd)
             self.login_edit.setDisabled(True)
-            self.service_edit = QtGui.QLabel(default.get_name(), self)
+            self.service_edit = QtGui.QLabel(default.get_name(), self.centr_widg)
             grid.addWidget(self.service_edit, 2, 1, 1, 4, QtCore.Qt.AlignLeft)
             grid.addWidget(self.serv_combo, 3, 1, 1, 4, QtCore.Qt.AlignLeft)
             grid.setRowStretch(3, 2)
@@ -77,23 +80,27 @@ class AddProfileWindow(StartPage):
             grid.setRowStretch(2, 2)
         grid.setColumnStretch(0, 1)
         grid.setColumnStretch(1, 3)
+        self.setCentralWidget(self.centr_widg)
 
 
         self.hbox_add.addWidget(toolbar)
         self.hbox_add.addSpacing(10)
         self.hbox_add.addLayout(grid)
-        self.setLayout(self.hbox_add)
-
-
+        self.centr_widg.setLayout(self.hbox_add)
+        
+        self.show()
+    
     def create_toolbar(self):
         """
         create profile for "add profile" window
         @return
         """
-        file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
+        file_tool_bar = ToolbarWindow(parent=self.centr_widg)
         if self.default:
-            file_tool_bar.addAction(self.del_act)
-        file_tool_bar.addAction(self.add_acc)
+            file_tool_bar.addWidget(self.del_act)
+        file_tool_bar.addWidget(self.add_acc)
+        self.connect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
+                             self.home_window)                             
         return file_tool_bar
 
     def create_actions(self):
@@ -101,12 +108,12 @@ class AddProfileWindow(StartPage):
         create buttons for toolbar
         @return
         """
-        self.add_acc = QtGui.QToolButton(self)
+        self.add_acc = QtGui.QToolButton(self.centr_widg)
         self.connect(self.add_acc, QtCore.SIGNAL("clicked()"),
                      self.add_account)
         if self.default:
-            self.del_act = QtGui.QToolButton(self)
-            self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/remove_profile.png")))
+            self.del_act = QtGui.QToolButton(self.centr_widg)
+            self.del_act.setIcon(QtGui.QIcon("../data/en/remove_profile.png"))
             self.del_act.setText(self.tr("Delete account"))
             self.del_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
             self.del_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -116,7 +123,7 @@ class AddProfileWindow(StartPage):
             self.add_acc.setText(self.tr("OK"))
         else:
             self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/add_profile.png")))
-            self.add_acc.setText(self.tr("Add profile"))
+            self.add_acc.setText(self.tr("Add account"))
 
         self.add_acc.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.add_acc.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
@@ -129,7 +136,7 @@ class AddProfileWindow(StartPage):
          manage account
         @return acc_combo pop-up list with accounts or services
         """
-        acc_combo = QtGui.QComboBox(self)
+        acc_combo = QtGui.QComboBox(self.centr_widg)
         self.accounts2 = []
         if default:
             self.accounts2.append(default)
@@ -191,7 +198,7 @@ class AddProfileWindow(StartPage):
             ret = self._add_new_account()
 
         if ret:
-            main_window.home_window()
+            super(AddProfileWindow, self).home_window()
 
 
 
@@ -206,13 +213,13 @@ class AddProfileWindow(StartPage):
             self.default.check_login()
         except WarningExc, exc:
             self.default.passwd = old_pass
-            main_window.show_warning(exc)
+            super(MainWindow,self).show_warning(exc)
             return False
 
         try:
             self.default.refresh_user_info()
         except WarningExc, exc:
-            main_window.show_warning(exc)
+            super(MainWindow,self).show_warning(exc)
 
         self.default.set_default()
 
@@ -247,7 +254,7 @@ class AddProfileWindow(StartPage):
         else:
             #all accounts are deleted
             main_prof.remove_account(del_acc)
-        main_window.home_window()
+        super(MainWindow, self).home_window()
 
 
 #from MainWindow import *
