@@ -4,12 +4,12 @@
   File is a part of Scribo Project  
   Module implements home window from UI
   @author: Zaiceva Diana <zaiceva@cs.karelia.ru>
-  @date: 23.02.2010
+  @date: 23.06.2010
 """
 
 __author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
-__version__ = "$Revision: 0.1 $"
-__date__ = "$Date: 2010/02/23 $"
+__version__ = "$Revision: 0.2 $"
+__date__ = "$Date: 2010/06/23 $"
 __copyright__ = ""
 __license__ = "GPLv2"
 
@@ -26,9 +26,9 @@ from PyQt4 import QtGui
 
 from ldm.Profile import main_prof
 from ldm.Account import *
+from MainWindow import *
 
-
-class HomePage(QtGui.QWidget):
+class HomePage(MainWindow):
     """
     home window for UI
     @version  1.0   
@@ -40,16 +40,22 @@ class HomePage(QtGui.QWidget):
         @param parent (widget) 
         @return 
         """
-        QtGui.QWidget.__init__(self, parent.centralWidget())
-        self.mainwindow = parent
-        self.account = []
-        self.vboxmain = QtGui.QVBoxLayout()
-        self.vboxmain.addLayout(self.create_info_group())
-        self.vboxmain.addSpacing(20)
-        self.vboxmain.addLayout(self.create_push_button_group(), 2)
-        self.vboxmain.addSpacing(20)
-        self.setLayout(self.vboxmain)
-
+        if not main_prof.accounts:
+            print "starts"
+            from StartPage import start_page
+        else:    
+            super(HomePage, self).__init__(parent = None)
+            self.parent = parent
+            self.centr_widg = QtGui.QWidget(self) 
+            self.account = []
+            self.vboxmain = QtGui.QVBoxLayout()
+            self.vboxmain.addLayout(self.create_info_group())
+            self.vboxmain.addSpacing(20)
+            self.vboxmain.addLayout(self.create_push_button_group(), 2)
+            self.vboxmain.addSpacing(20)
+            self.centr_widg.setLayout(self.vboxmain)
+            self.setCentralWidget(self.centr_widg)
+            self.show()
 
     def create_list_acc(self, def_acc):
         '''        
@@ -58,7 +64,7 @@ class HomePage(QtGui.QWidget):
         @return acc_combo
         '''
         self.account = []
-        acc_combo = QtGui.QComboBox(self)
+        acc_combo = QtGui.QComboBox(self.centr_widg)
         path_ava = def_acc.path_to_ava
         # if user haven't userpic on service, it isn't added. 
         if not path_ava:
@@ -135,10 +141,10 @@ class HomePage(QtGui.QWidget):
         def_acc = main_prof.def_account
         #label with personal information
 
-        self.info_label = QtGui.QLabel(self.fill_user_info(def_acc), self)
+        self.info_label = QtGui.QLabel(self.fill_user_info(def_acc), self.centr_widg)
         self.info_label.setAlignment(QtCore.Qt.AlignLeft)
 
-        self.image_label = QtGui.QLabel(self.tr("Photo"), self)
+        self.image_label = QtGui.QLabel(self.tr("Photo"), self.centr_widg)
         self.image_label.setAlignment(QtCore.Qt.AlignCenter)
 
         self.acc_combo_box = self.create_list_acc(def_acc)
@@ -167,9 +173,9 @@ class HomePage(QtGui.QWidget):
         @return
         """
 
-        add_post_button = QtGui.QPushButton(self.tr("&Add post"), self)
-        my_post_button = QtGui.QPushButton(self.tr("&My posts"), self)
-        friends_posts_btn = QtGui.QPushButton(self.tr("&Friends' posts"), self)
+        add_post_button = QtGui.QPushButton(self.tr("&Add post"), self.centr_widg)
+        my_post_button = QtGui.QPushButton(self.tr("&My posts"), self.centr_widg)
+        friends_posts_btn = QtGui.QPushButton(self.tr("&Friends' posts"), self.centr_widg)
 
         add_post_button.setIcon(QtGui.QIcon(self.tr("../data/en/add_post.png")))
         my_post_button.setIcon(QtGui.QIcon(self.tr("../data/en/my_posts.png")))
@@ -181,11 +187,43 @@ class HomePage(QtGui.QWidget):
         hbox.addWidget(friends_posts_btn, -1, QtCore.Qt.AlignCenter)
 
         self.connect(add_post_button, QtCore.SIGNAL("clicked()"),
-                     self.mainwindow.add_post)
+                     self.add_post)
         self.connect(my_post_button, QtCore.SIGNAL("clicked()"),
-                     self.mainwindow.list_my_posts)
+                     self.list_my_posts)
         self.connect(friends_posts_btn, QtCore.SIGNAL("clicked()"),
-                     self.mainwindow.list_friends_posts)
+                     self.list_friends_posts)
         return hbox
 
+    def add_post(self):
+        """                                                                                                                                                 
+        handler for clicked "add_post"                                                                                                                      
+        @param                                                                                                                                              
+        @return                                                                                                                                             
+        """
 
+        from AddPost import AddPostWindow
+        add_widg = AddPostWindow(self)
+    
+
+
+    def list_my_posts(self):
+        """                                                                                                                                                 
+        handler for clicked "my_posts"                                                                                                                      
+        @param                                                                                                                                              
+        @return                                                                                                                                             
+        """
+        from ListMyPosts import ListMyPosts
+        widg = ListMyPosts(self)
+    
+
+
+    def list_friends_posts(self):
+        """                                                                                                                                                 
+        handler for clicked "friends posts"
+        @param                                                                                                                                              
+        @return                                                                                                                                             
+        """
+        from ListFriendsPosts import ListFriendsPosts
+        widg = ListFriendsPosts(self)
+    
+#home_window = HomePage()
\ No newline at end of file
