@@ -4,7 +4,7 @@
   File is a part of Scribo Project
   Module implements repeating send posts from UI
   @author: Zaiceva Diana <zaiceva@cs.karelia.ru>
-  @date: 25.03.2010
+  @date: 26.06.2010
 """
 import sys
 #sys.path.append("./src/services")
@@ -13,16 +13,17 @@ sys.path.append("./src/ldm")
 from PyQt4 import QtCore
 from PyQt4 import QtGui
 
-from MainWindow import main_window
+#from HomePage import home_window
+from MainWindow import *
 from ToolbarWindow import ToolbarWindow
 
 __author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
-__version__ = "$Revision: 0.1 $"
-__date__ = "$Date: 2010/03/25 $"
+__version__ = "$Revision: 0.2 $"
+__date__ = "$Date: 2010/06/26 $"
 __copyright__ = ""
 __license__ = "GPLv2"
 
-class RepeatPost(QtGui.QWidget):
+class RepeatPost(MainWindow):
     """
     class for window with a tree accounts
     @version  1.0
@@ -33,9 +34,11 @@ class RepeatPost(QtGui.QWidget):
         initialization "tree of messages" window
         @return
         """
-        QtGui.QWidget.__init__(self, parent.centralWidget())
+        super(RepeatPost,self).__init__(parent)
         self.mes = msg
+        self.centr_widg = QtGui.QWidget(self)
         self.tree_view = self.tree_view_acc()
+        self.parent = parent
         #super(RepeatPost, self).create_actions()
         title = QtGui.QLabel(self.tr("Select accounts and groups for sending"), self)
         title.setAlignment(QtCore.Qt.AlignLeft)
@@ -47,24 +50,25 @@ class RepeatPost(QtGui.QWidget):
         self.vbox.addWidget(title)
         self.vbox.addWidget(self.tree_view)
         self.hbox.addLayout(self.vbox)
-        self.setLayout(self.hbox)
-
+        self.centr_widg.setLayout(self.hbox)
+        self.setCentralWidget(self.centr_widg)
+        self.show()
 
     def create_toolbar(self):
         """
         create toolbar for window
         @return
         """
-        file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
-        self.send_act = QtGui.QToolButton(self)
+        file_tool_bar = ToolbarWindow(parent=self.centr_widg)
+        self.send_act = QtGui.QToolButton(self.centr_widg)
         self.send_act.setIcon(QtGui.QIcon(self.tr("../data/en/send_post.png")))
         self.send_act.setText(self.tr("Send"))
         self.send_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.send_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.send_act, QtCore.SIGNAL("clicked()"), self.send_selected)
         file_tool_bar.addWidget(self.send_act)
-        self.disconnect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
-                     main_window.home_window)
+        #self.disconnect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
+        #             main_window.home_window)
         self.connect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
                      self.home_window)
         return file_tool_bar
@@ -84,20 +88,20 @@ class RepeatPost(QtGui.QWidget):
             self.all_acc.append(acc)
             path_icon = acc.get_icon()
 
-            login = QtGui.QTreeWidgetItem(tree_widget)
-            login.setFlags(login.flags() | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsSelectable)
+            self.login = QtGui.QTreeWidgetItem(tree_widget)
+            self.login.setFlags(QtCore.Qt.NoItemFlags| QtCore.Qt.ItemIsEnabled)
             # if user haven't userpic on service, it isn't added. 
             if path_icon:
-                login.setIcon(0, QtGui.QIcon(QtCore.QString(path_icon)))
+                self.login.setIcon(0, QtGui.QIcon(QtCore.QString(path_icon)))
             else:
-                login.setIcon(0, QtGui.QIcon())
+                self.login.setIcon(0, QtGui.QIcon())
 
-            login.setText(1, acc.username)
-            login.setData(1, QtCore.Qt.CheckStateRole, QtCore.QVariant(QtCore.Qt.Unchecked))
+            self.login.setText(1, acc.username)
+            self.login.setData(1, QtCore.Qt.DisplayRole, QtCore.QVariant(acc.username))
 
-            child_login = QtGui.QTreeWidgetItem(login)
+            child_login = QtGui.QTreeWidgetItem(self.login)
 
-            child_login.setFlags(child_login.flags() | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsEnabled)
+            child_login.setFlags(QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsSelectable)
             child_login.setText(1, acc.username)
 
             child_login.setData(1, QtCore.Qt.CheckStateRole, QtCore.QVariant(QtCore.Qt.Unchecked))
@@ -111,8 +115,8 @@ class RepeatPost(QtGui.QWidget):
             else:
                 len_groups = 0
             for l in xrange(len_groups):
-                group_login = QtGui.QTreeWidgetItem(login)
-                group_login.setFlags(group_login.flags() | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsSelectable)
+                group_login = QtGui.QTreeWidgetItem(self.login)
+                group_login.setFlags(QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsEnabled |QtCore.Qt.ItemIsSelectable)
                 group_login.setText(1, groups[l].username)
                 group_login.setData(1, QtCore.Qt.CheckStateRole,
                                      QtCore.QVariant(QtCore.Qt.Unchecked))
@@ -120,21 +124,22 @@ class RepeatPost(QtGui.QWidget):
                 self.all_acc.append(groups[l])
                 index = index + 1
 
-            accounts.append(login)
+            accounts.append(self.login)
         tree_widget.insertTopLevelItems(0, accounts)
         self.connect(tree_widget,
-                      QtCore.SIGNAL("itemClicked (QTreeWidgetItem *,int)"), self.click_item)
+                      QtCore.SIGNAL("itemActivated (QTreeWidgetItem *,int)"), self.click_item)
         return tree_widget
 
+
     def click_item(self, item, column):
-        if column <> 1:
+        if item.parent():
             select = item.data(1, QtCore.Qt.CheckStateRole).toString().toInt()[0]
-            if select == QtCore.Qt.Unchecked:
-                item.setData(1, QtCore.Qt.CheckStateRole,
-                                         QtCore.QVariant(QtCore.Qt.Checked))
-            else:
+            if select == QtCore.Qt.Checked:
                 item.setData(1, QtCore.Qt.CheckStateRole,
                                          QtCore.QVariant(QtCore.Qt.Unchecked))
+            else:
+                item.setData(1, QtCore.Qt.CheckStateRole,
+                                         QtCore.QVariant(QtCore.Qt.Checked))
 
     def send_selected(self):
         login_items = self.tree_view.selectedItems()
@@ -163,7 +168,7 @@ class RepeatPost(QtGui.QWidget):
                 try:
                     res = send_acc.send_post(msg_copy)
                 except WarningExc, exc:
-                    main_window.show_warning(exc)
+                    super(RepeatPost, self).show_warning(exc)
                     flag_send = False
 
                 msg_copy.del_msg_tree()
@@ -178,7 +183,8 @@ class RepeatPost(QtGui.QWidget):
             ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                                 self.tr("Post was sent"),
                                                 QtGui.QMessageBox.Yes)
-        main_window.home_window()
+            self.parent.sending_post = True
+        super(RepeatPost, self).home_window()
 
     def home_window(self):
         """
@@ -191,7 +197,6 @@ class RepeatPost(QtGui.QWidget):
                                QtGui.QMessageBox.No)
         if (ret == QtGui.QMessageBox.No):
                 return
-        main_window.home_window()
-
-
+        super(RepeatPost, self).home_window()
+        
 from AddPost import *
