@@ -4,7 +4,7 @@
   File is a part of Scribo Project
   Module implements viewing tree of comments from UI
   @author: Zaiceva Diana <zaiceva@cs.karelia.ru>
-  @date: 06.01.2010
+  @date: 23.06.2010
 """
 import sys
 #sys.path.append("./src/services")
@@ -13,16 +13,16 @@ import sys
 from PyQt4 import QtCore
 from PyQt4 import QtGui
 
-from MainWindow import main_window
+from MainWindow import *
 from ToolbarWindow import ToolbarWindow
 
 __author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
-__version__ = "$Revision: 0.1 $"
-__date__ = "$Date: 2010/01/06 $"
+__version__ = "$Revision: 0.2 $"
+__date__ = "$Date: 2010/06/23 $"
 __copyright__ = ""
 __license__ = "GPLv2"
 
-class TreeMessage(QtGui.QWidget):
+class TreeMessage(MainWindow):
     """
     class for draw tree of comments window
     @version  1.0
@@ -34,7 +34,9 @@ class TreeMessage(QtGui.QWidget):
         initialization "tree of messages" window
         @return
         """
-        QtGui.QWidget.__init__(self, parent.centralWidget())
+        super(TreeMessage, self).__init__(parent)
+        self.parent = parent
+        self.centr_widg = QtGui.QWidget(self)
         self.msg = msg
         self.tree_view = self.tree_view_com(msg)
         self.create_actions()
@@ -43,8 +45,9 @@ class TreeMessage(QtGui.QWidget):
         self.hbox.addWidget(toolbar)
         self.hbox.addSpacing(10)
         self.hbox.addWidget(self.tree_view)
-        self.setLayout(self.hbox)
-
+        self.centr_widg.setLayout(self.hbox)
+        self.setCentralWidget(self.centr_widg)
+        self.show()
 
     def tree_view_com(self, msg):
         """ 
@@ -52,7 +55,7 @@ class TreeMessage(QtGui.QWidget):
         @param                                          
         @return
         """
-        tree_view = QtGui.QTreeView(self)
+        tree_view = QtGui.QTreeView(self.centr_widg)
         tree_view.setModel(MyModel(msg=msg))
         return tree_view
 
@@ -61,8 +64,11 @@ class TreeMessage(QtGui.QWidget):
         create profile for "add profile" window
         @return
         """
-        file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
+        file_tool_bar = ToolbarWindow(parent=self.centr_widg)
         file_tool_bar.addWidget(self.refresh_act)
+        self.connect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
+                             self.home_window)
+
         return file_tool_bar
 
     def create_actions(self):
@@ -71,21 +77,22 @@ class TreeMessage(QtGui.QWidget):
         @return
         """
 
-        self.refresh_act = QtGui.QToolButton(self)
+        self.refresh_act = QtGui.QToolButton(self.centr_widg)
         self.refresh_act.setIcon(QtGui.QIcon(self.tr("../data/en/refresh.png")))
         self.refresh_act.setText(self.tr("Refresh"))
         self.refresh_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.refresh_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.refresh_act, QtCore.SIGNAL("clicked()"),
                      self.reload_window)
+        
 
     def view_message(self):
         """  
         view choosing message
         @return
         """
-        view_widg = ViewMessage(main_window)
-        main_window.push_window(view_widg)
+        view_widg = ViewMessage(self)
+        
 
     def reload_window(self):
         """ 
